package com.nexo.model.douyin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.nexo.common.core.utils.OkHttpClientUtils;
import com.nexo.common.core.utils.StringUtils;
import com.nexo.common.mybatis.core.page.PageQuery;
import com.nexo.common.mybatis.core.page.TableDataInfo;
import com.nexo.common.redis.utils.RedisUtils;
import com.nexo.common.satoken.utils.LoginHelper;
import com.nexo.model.douyin.domain.UpdataStatusBo;
import com.nexo.model.douyin.mapper.NexoDouyinUserInfoMapper;
import com.nexo.model.douyin.service.INexoDouyinUserInfoService;
import com.nexo.module.api.douyin.domain.NexoDouyinUserInfo;
import com.nexo.module.api.douyin.utils.DouYinUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 抖音用户信息Service业务层处理
 *
 * @author nexo
 * @date 2026-05-21
 */
@RequiredArgsConstructor
@Service
@Slf4j
public class NexoDouyinUserInfoServiceImpl implements INexoDouyinUserInfoService {

    private final NexoDouyinUserInfoMapper baseMapper;

    @Value("${spring.profiles.active}")
    private String activeProfile;

    /**
     * 查询抖音用户信息
     */
    @Override
    public NexoDouyinUserInfo queryById(String userId) {
        return baseMapper.selectById(userId);
    }

    /**
     * 查询抖音用户信息列表
     */
    @Override
    public TableDataInfo<NexoDouyinUserInfo> queryPageList(NexoDouyinUserInfo item, PageQuery pageQuery) {
        LambdaQueryWrapper<NexoDouyinUserInfo> lqw = buildQueryWrapper(item);
        Page<NexoDouyinUserInfo> result = baseMapper.selectPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询抖音用户信息列表
     */
    @Override
    public List<NexoDouyinUserInfo> queryList(NexoDouyinUserInfo item) {
        LambdaQueryWrapper<NexoDouyinUserInfo> lqw = buildQueryWrapper(item);
        return baseMapper.selectList(lqw);
    }

    private LambdaQueryWrapper<NexoDouyinUserInfo> buildQueryWrapper(NexoDouyinUserInfo item) {
        Map<String, Object> params = item.getParams();
        LambdaQueryWrapper<NexoDouyinUserInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(item.getSecUid()), NexoDouyinUserInfo::getSecUid, item.getSecUid());
        lqw.eq(StringUtils.isNotBlank(item.getUniqueId()), NexoDouyinUserInfo::getUniqueId, item.getUniqueId());
        lqw.like(StringUtils.isNotBlank(item.getNickname()), NexoDouyinUserInfo::getNickname, item.getNickname());
        lqw.eq(StringUtils.isNotBlank(item.getSignature()), NexoDouyinUserInfo::getSignature, item.getSignature());
        lqw.eq(StringUtils.isNotBlank(item.getIpLocation()), NexoDouyinUserInfo::getIpLocation, item.getIpLocation());
        lqw.eq(StringUtils.isNotBlank(item.getAvatar()), NexoDouyinUserInfo::getAvatar, item.getAvatar());
        lqw.eq(item.getLiveStatus() != null, NexoDouyinUserInfo::getLiveStatus, item.getLiveStatus());
        lqw.eq(item.getUserAge() != null, NexoDouyinUserInfo::getUserAge, item.getUserAge());
        lqw.eq(item.getTotalFavorited() != null, NexoDouyinUserInfo::getTotalFavorited, item.getTotalFavorited());
        lqw.eq(item.getFollowerCount() != null, NexoDouyinUserInfo::getFollowerCount, item.getFollowerCount());
        lqw.eq(item.getFollowingCount() != null, NexoDouyinUserInfo::getFollowingCount, item.getFollowingCount());
        lqw.eq(item.getAwemeCount() != null, NexoDouyinUserInfo::getAwemeCount, item.getAwemeCount());
        lqw.eq(StringUtils.isNotBlank(item.getCoverUrl()), NexoDouyinUserInfo::getCoverUrl, item.getCoverUrl());
        lqw.eq(StringUtils.isNotBlank(item.getRoomId()), NexoDouyinUserInfo::getRoomId, item.getRoomId());
        return lqw;
    }

    /**
     * 新增抖音用户信息
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean insertBy(NexoDouyinUserInfo item) {
        String string = DouYinUtils.getRegexString(item.getUserUrl(), "[a-zA-z]+://[^\\s]*", 0);
        String done = OkHttpClientUtils.doGetFollowRedirects(string, null);
        String mid = item.getUserUrl();
        if (string.contains("v.douyin.com")) {
            try {
                mid = URLDecoder.decode(StringUtils.extractMiddleText(done, "\"", "\""), "UTF-8");
            } catch (UnsupportedEncodingException e) {
                throw new RuntimeException(e);
            }
        }
        String sec_user_id = DouYinUtils.getRegexString(mid, "user/(.*?)\\?", 0);
        sec_user_id = StringUtils.extractMiddleText(sec_user_id, "user/", "?");
        LambdaQueryWrapper<NexoDouyinUserInfo> lambdaed = Wrappers.lambdaQuery();
        lambdaed.eq(NexoDouyinUserInfo::getSecUid, sec_user_id);
        NexoDouyinUserInfo userInfo = baseMapper.selectVoOne(lambdaed);
        if (userInfo != null) {
            if (userInfo.getCreateBy().equals(LoginHelper.getUsername())) {
                throw new RuntimeException("用户已存在");
            }
            return true;
        }
        log.info("activeProfile:{}", activeProfile);
        log.info("douyin_config_dev:{}", RedisUtils.getCacheMapValue("sys_config", "douyin_config_dev").toString());
        log.info("douyin_config_pord:{}", RedisUtils.getCacheMapValue("sys_config", "douyin_config_pord").toString());
        item = DouYinUtils.getUserInfo(sec_user_id, !activeProfile.equals("prod") ? RedisUtils.getCacheMapValue("sys_config", "douyin_config_dev") : RedisUtils.getCacheMapValue("sys_config", "douyin_config_pord"));
        item.setDeptId(LoginHelper.getDeptId());
        Boolean flag = baseMapper.insert(item) > 0;
        return flag;
    }

    /**
     * 修改抖音用户信息
     */
    @Override
    public Boolean updateBy(NexoDouyinUserInfo item) {
        return baseMapper.updateById(item) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(NexoDouyinUserInfo entity) {
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除抖音用户信息
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if (isValid) {
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }

    @Override
    public Boolean updateMonitorState(UpdataStatusBo item) {
        NexoDouyinUserInfo userInfo = new NexoDouyinUserInfo();
        userInfo.setId(item.getId());
        userInfo.setJobInfoStatus(item.getJobInfoStatus());
        userInfo.setJobLiveStatus(item.getJobLiveStatus());
        userInfo.setJobVideoStatus(item.getJobVideoStatus());
        return baseMapper.updateById(userInfo) > 0;
    }

}
